Skip to contents

This package allows NSW Government R users to create data visualisations in keeping with the NSW Design System. This ensures a consistent approach to data visualisations with appropriate colours and fonts. This package was inspired by the data viz work of Cara Thompson https://github.com/cararthompson.

Author

Maintainer: Zoe Baldwin zoe.baldwin@health.nsw.gov.au (ORCID)

Other contributors: