Unlike pal_nsw(), pal_waratah() is not based strictly on the NSW colour
palette grids.
It tries to choose colours that are perceptually distinct, optionally taking
into account colour-blindness when doing so.
Arguments
- type
type of palette that should be generated:
"qual"discrete qualitative palette"seq"continuous sequential palette: a gradient spanning extreme tones ofhue"div"continuous diverging palette: a gradient spanning extreme tones ofhueand a second distinct colour."pairs","triples"like `"qual"“ but in sets of 2 or 2 tones of each hue.
- hue
main hue, either by name of index. See
col_nsw()for supported values. Only used whentypeis"seq"or"div".- cvd
when
TRUEaccount for colour vision disorders. Requires thecolorBlindnesspackage.- variant
name of palette variant. Available options are: base, aboriginal, corporate, treasury. Ignored unless
hueortoneis specified.- direction
set to -1 to reverse the order of colours in the palette, or 1 for the original order.
Value
A palette object (see palette constructors)
See also
Other palettes:
pal_nsw()